#
#  Tables for ADC2000NG Pro
#
#  ADC2000NG Pro - banner exchange software
#  Copyright (C) 1998-2010  T&D Systems, Inc.
#  http://www.td-systems.com/
#  
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#  
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#  
#  You should have received a copy of the GNU General Public License
#  along with this program.  If not, see <http://www.gnu.org/licenses/>.
# -----------------------------------------------------------------------

#usr_aflag	- Active/Inactive
#usr_fflag	- Flash stats
#usr_tflag	- Regular/Trusted
#usr_eflag	- Expirable/Non-expirable
#usr_pflag	- Public attributes
#usr_advflag	- Free/Advertiser
#usr_autoflag	- Approval required/Auto-accept
#usr_targetype  - Target type (_top/_blank)

CREATE TABLE user (
usr_id          MEDIUMINT(8) UNSIGNED NOT NULL auto_increment,
wusr_id         MEDIUMINT(8) UNSIGNED DEFAULT '0' NOT NULL,
usr_login       VARCHAR(8) NOT NULL,
usr_passwd      VARCHAR(8) NOT NULL,
usr_aflag       TINYINT(1) UNSIGNED DEFAULT '1' NOT NULL,
usr_fflag       TINYINT(1) UNSIGNED DEFAULT '0' NOT NULL,
usr_tflag       TINYINT(1) UNSIGNED DEFAULT '0' NOT NULL,
usr_eflag       TINYINT(1) UNSIGNED DEFAULT '0' NOT NULL,
usr_advflag     TINYINT(1) UNSIGNED DEFAULT '0' NOT NULL,
usr_autoflag    TINYINT(1) UNSIGNED DEFAULT '0' NOT NULL,
usr_targetype   TINYINT(1) UNSIGNED DEFAULT '0' NOT NULL,
usr_weight      TINYINT(2) UNSIGNED DEFAULT '1' NOT NULL,
usr_activity    DATE NOT NULL,
cntr_id         MEDIUMINT(4) UNSIGNED NOT NULL,
grp_acounter    MEDIUMINT(9) UNSIGNED DEFAULT '1' NOT NULL,
                PRIMARY KEY (usr_id),
                UNIQUE (usr_id,usr_login),
                INDEX (usr_id,wusr_id,usr_activity,cntr_id,usr_aflag)
);

#alter table user add usr_targetype TINYINT(1) UNSIGNED DEFAULT '0' NOT NULL;
#alter table user add grp_acounter MEDIUMINT(9) UNSIGNED DEFAULT '1' NOT NULL;

CREATE TABLE user_attr (
usr_id          MEDIUMINT(8) UNSIGNED NOT NULL,
usr_pflag       TINYINT(1) UNSIGNED DEFAULT '0' NOT NULL,
usr_name        VARCHAR(60) NOT NULL,
usr_addr        VARCHAR(60) NOT NULL,
usr_city        VARCHAR(30) NOT NULL,
usr_email       VARCHAR(50) NOT NULL,
usr_emflag      TINYINT(1) UNSIGNED DEFAULT '1' NOT NULL,
usr_phone       VARCHAR(30) NOT NULL,
usr_zip         VARCHAR(30) NOT NULL,
usr_comment     VARCHAR(100),
                INDEX (usr_id,usr_pflag)
);

#alter table user_attr add usr_comment VARCHAR(100);

CREATE TABLE country (
cntr_id         MEDIUMINT(4) UNSIGNED NOT NULL auto_increment,
cntr_name       VARCHAR(35) NOT NULL,
                PRIMARY KEY (cntr_id),
                INDEX (cntr_id)
);

CREATE TABLE category (
category_id     SMALLINT(3) UNSIGNED NOT NULL auto_increment,
category        VARCHAR(65) NOT NULL,
                PRIMARY KEY (category_id),
                INDEX (category_id)
);

#CREATE TABLE domains (
#dom_id		SMALLINT(3) UNSIGNED NOT NULL auto_increment,
#dom_name	VARCHAR(45) NOT NULL,
#dom_sname	VARCHAR(3) NOT NULL,
#		PRIMARY KEY (dom_id),
#		INDEX (dom_id)
#);

CREATE TABLE credits (
usr_id          MEDIUMINT(8) UNSIGNED NOT NULL,
usr_tflag       TINYINT(1) UNSIGNED DEFAULT '0' NOT NULL,
click           FLOAT(9,2) NOT NULL,
impression      FLOAT(9,2) NOT NULL,
clk_ratio       VARCHAR(7) NOT NULL,
imp_ratio       VARCHAR(7) NOT NULL,
ref_users       MEDIUMINT(6) UNSIGNED NOT NULL DEFAULT '0',
ref_ratio       VARCHAR(7) NOT NULL,
ern_credits     FLOAT(9,2) NOT NULL DEFAULT '0',
last_impress    VARCHAR(22) DEFAULT '(N/A)' NOT NULL,
last_click      VARCHAR(22) DEFAULT '(N/A)' NOT NULL,
                INDEX (usr_id)
);

CREATE TABLE credit_stats (
usr_id          MEDIUMINT(8) UNSIGNED NOT NULL,
j_date          VARCHAR(12) NOT NULL,
j_impress       MEDIUMINT(9) NOT NULL DEFAULT '0',
j_clicks        MEDIUMINT(9) NOT NULL DEFAULT '0',
lr_date         VARCHAR(12) NOT NULL,
lr_impress      MEDIUMINT(9) NOT NULL DEFAULT '0',
lr_clicks       MEDIUMINT(9) NOT NULL DEFAULT '0',
afl_impress     MEDIUMINT(9) NOT NULL DEFAULT '0',
afl_clicks      MEDIUMINT(9) NOT NULL DEFAULT '0',
trf_impress     MEDIUMINT(9) NOT NULL DEFAULT '0',
trf_clicks      MEDIUMINT(9) NOT NULL DEFAULT '0',
trf_from        VARCHAR(8) DEFAULT '(N/A)' NOT NULL,
trf_date        VARCHAR(12) DEFAULT '(N/A)' NOT NULL,
                INDEX (usr_id)
);

CREATE TABLE ban_group (
grp_id          MEDIUMINT(8) UNSIGNED NOT NULL auto_increment,
usr_id          MEDIUMINT(8) UNSIGNED NOT NULL,
category_id     SMALLINT(3) UNSIGNED DEFAULT '1' NOT NULL,
grp_name        VARCHAR(50) DEFAULT '(N/A)' NOT NULL,
grp_catswitch   TINYINT(1) UNSIGNED DEFAULT '0' NOT NULL,
grp_couswitch   TINYINT(1) UNSIGNED DEFAULT '0' NOT NULL,
grp_atswitch    TINYINT(1) UNSIGNED DEFAULT '0' NOT NULL,
grp_adswitch    TINYINT(1) UNSIGNED DEFAULT '0' NOT NULL,
grp_amswitch    TINYINT(1) UNSIGNED DEFAULT '0' NOT NULL,
grp_tcategory   BLOB NOT NULL,
grp_bcategory   BLOB NOT NULL,
grp_tcountry    BLOB NOT NULL,
#grp_start      DATE,
#grp_stop       DATE,
grp_impress     MEDIUMINT(9) NOT NULL DEFAULT '0',
grp_clicks      MEDIUMINT(9) NOT NULL DEFAULT '0',
                PRIMARY KEY (grp_id),
                INDEX (grp_id,usr_id,category_id)
);

#alter table ban_group change grp_name grp_name VARCHAR(50) DEFAULT '(N/A)' NOT NULL;

CREATE TABLE banner (
ban_id          INT UNSIGNED NOT NULL auto_increment,
grp_id          MEDIUMINT(8) UNSIGNED NOT NULL,
usr_id          MEDIUMINT(8) UNSIGNED NOT NULL,
ban_type        TINYINT(2) UNSIGNED NOT NULL,
ban_name        VARCHAR(50) DEFAULT '(N/A)' NOT NULL,
ban_file        VARCHAR(36),
ban_cnt         MEDIUMINT(8) UNSIGNED NOT NULL,
ban_res         TINYINT(2) UNSIGNED NOT NULL,
ban_swim        TINYINT(1) UNSIGNED NOT NULL DEFAULT '0',
ban_url         VARCHAR(100) NOT NULL,
ban_upload      VARCHAR(12) NOT NULL DEFAULT 'not uploaded',
ban_acpflag     TINYINT(1) UNSIGNED NOT NULL DEFAULT '0',
ban_reject      VARCHAR(150),
ban_reject_date VARCHAR(12),
site_title      VARCHAR(40) NOT NULL,
site_desc       VARCHAR(150) NOT NULL,
ban_clicks      MEDIUMINT(9) NOT NULL DEFAULT '0',
ban_impress     MEDIUMINT(9) NOT NULL DEFAULT '0',
                PRIMARY KEY (ban_id),
                INDEX (ban_id,grp_id,usr_id,ban_type,ban_res,ban_upload,ban_acpflag)
);

#alter table banner change ban_name ban_name VARCHAR(50) DEFAULT '(N/A)' NOT NULL;

CREATE TABLE ban_counter (
usr_id          MEDIUMINT(8) UNSIGNED NOT NULL,
cnt_value       MEDIUMINT(8) UNSIGNED NOT NULL,
                INDEX (usr_id)
);

CREATE TABLE keywords (
ban_id          INT UNSIGNED NOT NULL,
keys_str        VARCHAR(200),
                INDEX (ban_id)
);

CREATE TABLE blitz_pool (
grp_id          MEDIUMINT(8) UNSIGNED NOT NULL,
usr_id          MEDIUMINT(8) UNSIGNED NOT NULL,
grp_name        VARCHAR(30) NOT NULL,
blitz_credit    MEDIUMINT(7) NOT NULL DEFAULT '0',
                INDEX (grp_id,usr_id)
);

CREATE TABLE adv_days (
usr_id          MEDIUMINT(8) UNSIGNED NOT NULL,
grp_id          MEDIUMINT(8) UNSIGNED NOT NULL,
day01           MEDIUMINT(9) NOT NULL DEFAULT '0',
day02           MEDIUMINT(9) NOT NULL DEFAULT '0',
day03           MEDIUMINT(9) NOT NULL DEFAULT '0',
day04           MEDIUMINT(9) NOT NULL DEFAULT '0',
day05           MEDIUMINT(9) NOT NULL DEFAULT '0',
day06           MEDIUMINT(9) NOT NULL DEFAULT '0',
day07           MEDIUMINT(9) NOT NULL DEFAULT '0',
day08           MEDIUMINT(9) NOT NULL DEFAULT '0',
day09           MEDIUMINT(9) NOT NULL DEFAULT '0',
day10           MEDIUMINT(9) NOT NULL DEFAULT '0',
day11           MEDIUMINT(9) NOT NULL DEFAULT '0',
day12           MEDIUMINT(9) NOT NULL DEFAULT '0',
day13           MEDIUMINT(9) NOT NULL DEFAULT '0',
day14           MEDIUMINT(9) NOT NULL DEFAULT '0',
day15           MEDIUMINT(9) NOT NULL DEFAULT '0',
day16           MEDIUMINT(9) NOT NULL DEFAULT '0',
day17           MEDIUMINT(9) NOT NULL DEFAULT '0',
day18           MEDIUMINT(9) NOT NULL DEFAULT '0',
day19           MEDIUMINT(9) NOT NULL DEFAULT '0',
day20           MEDIUMINT(9) NOT NULL DEFAULT '0',
day21           MEDIUMINT(9) NOT NULL DEFAULT '0',
day22           MEDIUMINT(9) NOT NULL DEFAULT '0',
day23           MEDIUMINT(9) NOT NULL DEFAULT '0',
day24           MEDIUMINT(9) NOT NULL DEFAULT '0',
day25           MEDIUMINT(9) NOT NULL DEFAULT '0',
day26           MEDIUMINT(9) NOT NULL DEFAULT '0',
day27           MEDIUMINT(9) NOT NULL DEFAULT '0',
day28           MEDIUMINT(9) NOT NULL DEFAULT '0',
day29           MEDIUMINT(9) NOT NULL DEFAULT '0',
day30           MEDIUMINT(9) NOT NULL DEFAULT '0',
day31           MEDIUMINT(9) NOT NULL DEFAULT '0',
c_day           TINYINT(2) NOT NULL,
cd_impress      FLOAT(9,2) NOT NULL DEFAULT '0',
                INDEX (usr_id,grp_id)
);

CREATE TABLE adv_time (
usr_id          MEDIUMINT(8) UNSIGNED NOT NULL,
grp_id          MEDIUMINT(8) UNSIGNED NOT NULL,
am00            MEDIUMINT(9) NOT NULL DEFAULT '0',
am01            MEDIUMINT(9) NOT NULL DEFAULT '0',
am02            MEDIUMINT(9) NOT NULL DEFAULT '0',
am03            MEDIUMINT(9) NOT NULL DEFAULT '0',
am04            MEDIUMINT(9) NOT NULL DEFAULT '0',
am05            MEDIUMINT(9) NOT NULL DEFAULT '0',
am06            MEDIUMINT(9) NOT NULL DEFAULT '0',
am07            MEDIUMINT(9) NOT NULL DEFAULT '0',
am08            MEDIUMINT(9) NOT NULL DEFAULT '0',
am09            MEDIUMINT(9) NOT NULL DEFAULT '0',
am10            MEDIUMINT(9) NOT NULL DEFAULT '0',
am11            MEDIUMINT(9) NOT NULL DEFAULT '0',
pm12            MEDIUMINT(9) NOT NULL DEFAULT '0',
pm13            MEDIUMINT(9) NOT NULL DEFAULT '0',
pm14            MEDIUMINT(9) NOT NULL DEFAULT '0',
pm15            MEDIUMINT(9) NOT NULL DEFAULT '0',
pm16            MEDIUMINT(9) NOT NULL DEFAULT '0',
pm17            MEDIUMINT(9) NOT NULL DEFAULT '0',
pm18            MEDIUMINT(9) NOT NULL DEFAULT '0',
pm19            MEDIUMINT(9) NOT NULL DEFAULT '0',
pm20            MEDIUMINT(9) NOT NULL DEFAULT '0',
pm21            MEDIUMINT(9) NOT NULL DEFAULT '0',
pm22            MEDIUMINT(9) NOT NULL DEFAULT '0',
pm23            MEDIUMINT(9) NOT NULL DEFAULT '0',
c_time          TINYINT(2) NOT NULL,
ct_impress      FLOAT(9,2) NOT NULL DEFAULT '0',
                INDEX (usr_id,grp_id)
);

CREATE TABLE adv_months (
usr_id          MEDIUMINT(8) UNSIGNED NOT NULL,
grp_id          MEDIUMINT(8) UNSIGNED NOT NULL,
mon01           MEDIUMINT(9) NOT NULL DEFAULT '0',
mon02           MEDIUMINT(9) NOT NULL DEFAULT '0',
mon03           MEDIUMINT(9) NOT NULL DEFAULT '0',
mon04           MEDIUMINT(9) NOT NULL DEFAULT '0',
mon05           MEDIUMINT(9) NOT NULL DEFAULT '0',
mon06           MEDIUMINT(9) NOT NULL DEFAULT '0',
mon07           MEDIUMINT(9) NOT NULL DEFAULT '0',
mon08           MEDIUMINT(9) NOT NULL DEFAULT '0',
mon09           MEDIUMINT(9) NOT NULL DEFAULT '0',
mon10           MEDIUMINT(9) NOT NULL DEFAULT '0',
mon11           MEDIUMINT(9) NOT NULL DEFAULT '0',
mon12           MEDIUMINT(9) NOT NULL DEFAULT '0',
c_month         TINYINT(2) NOT NULL,
cm_impress      FLOAT(9,2) NOT NULL DEFAULT '0',
                INDEX (usr_id,grp_id)
);

CREATE TABLE ext_stats (
ws_id           MEDIUMINT(8) UNSIGNED NOT NULL,
bo_id           MEDIUMINT(8) UNSIGNED NOT NULL,
ban_id          INT UNSIGNED NOT NULL,
ban_impress     MEDIUMINT(9) NOT NULL DEFAULT '0',
ban_clicks      MEDIUMINT(9) NOT NULL DEFAULT '0',
                INDEX (ws_id,bo_id,ban_id)
);

CREATE TABLE h_istats (
ban_id          INT UNSIGNED NOT NULL,
i_hr00          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr01          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr02          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr03          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr04          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr05          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr06          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr07          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr08          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr09          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr10          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr11          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr12          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr13          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr14          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr15          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr16          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr17          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr18          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr19          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr20          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr21          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr22          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr23          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_lu_day        TINYINT(2) UNSIGNED NOT NULL,
h_date          DATE,
                INDEX (ban_id)
);

CREATE TABLE h_cstats (
ban_id          INT UNSIGNED NOT NULL,
c_hr00          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_hr01          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_hr02          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_hr03          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_hr04          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_hr05          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_hr06          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_hr07          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_hr08          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_hr09          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_hr10          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_hr11          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_hr12          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_hr13          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_hr14          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_hr15          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_hr16          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_hr17          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_hr18          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_hr19          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_hr20          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_hr21          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_hr22          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_hr23          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_lu_day        TINYINT(2) UNSIGNED NOT NULL,
h_date          DATE,
                INDEX (ban_id)
);

CREATE TABLE m_istats (
ban_id          INT UNSIGNED NOT NULL,
i_ms01          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ms02          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ms03          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ms04          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ms05          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ms06          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ms07          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ms08          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ms09          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ms10          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ms11          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ms12          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_lu_year       SMALLINT(4) UNSIGNED NOT NULL,
                INDEX (ban_id)
);

CREATE TABLE m_cstats (
ban_id          INT UNSIGNED NOT NULL,
c_ms01          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_ms02          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_ms03          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_ms04          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_ms05          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_ms06          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_ms07          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_ms08          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_ms09          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_ms10          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_ms11          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_ms12          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_lu_year       SMALLINT(4) UNSIGNED NOT NULL,
                INDEX (ban_id)
);

CREATE TABLE d_istats (
ban_id          INT UNSIGNED NOT NULL,
i_ds01          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds02          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds03          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds04          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds05          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds06          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds07          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds08          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds09          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds10          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds11          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds12          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds13          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds14          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds15          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds16          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds17          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds18          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds19          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds20          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds21          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds22          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds23          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds24          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds25          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds26          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds27          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds28          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds29          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds30          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds31          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_lu_month      TINYINT(2) UNSIGNED NOT NULL,
d_date          VARCHAR(7),
                INDEX (ban_id)
);

CREATE TABLE d_cstats (
ban_id          INT UNSIGNED NOT NULL,
c_ds01          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_ds02          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_ds03          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_ds04          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_ds05          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_ds06          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_ds07          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_ds08          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_ds09          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_ds10          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_ds11          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_ds12          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_ds13          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_ds14          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_ds15          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_ds16          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_ds17          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_ds18          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_ds19          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_ds20          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_ds21          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_ds22          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_ds23          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_ds24          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_ds25          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_ds26          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_ds27          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_ds28          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_ds29          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_ds30          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_ds31          MEDIUMINT(9) NOT NULL DEFAULT '0',
c_lu_month      TINYINT(2) UNSIGNED NOT NULL,
d_date          VARCHAR(7),
                INDEX (ban_id)
);


#
# SERVER SETTINGS
# -----------------------------------------------------------------------

CREATE TABLE server_set (
login           VARCHAR(8) NOT NULL,
password        VARCHAR(8) NOT NULL,
aemail          VARCHAR(100) NOT NULL,
sys_lock        TINYINT(1) UNSIGNED DEFAULT '0' NOT NULL,
lock_flag       TINYINT(1) UNSIGNED DEFAULT '0' NOT NULL,
clkexch_flag    TINYINT(1) UNSIGNED DEFAULT '1' NOT NULL,
img_length      MEDIUMINT(7) UNSIGNED NOT NULL,
rich_length     MEDIUMINT(7) UNSIGNED NOT NULL,
max_subscr      MEDIUMINT(6) UNSIGNED NOT NULL,
adc_dir         VARCHAR(100) NOT NULL,
adc_dir_c       VARCHAR(100) NOT NULL,
banner_dir      VARCHAR(100) NOT NULL,
extitle         VARCHAR(60) NOT NULL,
alz_flag        TINYINT(1) UNSIGNED DEFAULT '1' NOT NULL,
log_ref         TINYINT(1) UNSIGNED DEFAULT '0' NOT NULL,
log_agent       TINYINT(1) UNSIGNED DEFAULT '0' NOT NULL,
log_coo         TINYINT(1) UNSIGNED DEFAULT '0' NOT NULL,
log_mod         TINYINT(1) UNSIGNED DEFAULT '0' NOT NULL,
impress_pb      MEDIUMINT(5) UNSIGNED NOT NULL,
clicks_pb       MEDIUMINT(5) UNSIGNED NOT NULL,
ip_limit        MEDIUMINT(5) UNSIGNED NOT NULL,
min_crt         FLOAT(5,2) UNSIGNED NOT NULL,
max_crt         FLOAT(5,2) UNSIGNED NOT NULL,
debug_flag      TINYINT(1) UNSIGNED DEFAULT '0' NOT NULL
);

insert into server_set values ("admin","password","dfr@td-systems.com",0,0,1,25000,60000,10,"http://www.yourhost.com/adc2000ng/","http://www.yourhost.com:8080/","http://www.yourhost.com/adc2000ng/banners/","T&D Banner Network",0,0,0,0,0,10,10,3,0.05,30,0);

#alter table server_set add log_mod TINYINT(1) UNSIGNED DEFAULT '0' NOT NULL;
#alter table server_set add adc_dir_c VARCHAR(100) NOT NULL;
#alter table server_set add debug_flag TINYINT(1) UNSIGNED DEFAULT '0' NOT NULL;

CREATE TABLE cengine (
cng_id          MEDIUMINT(8) UNSIGNED NOT NULL auto_increment,
cng_flag        VARCHAR(80) NOT NULL,
cng_value       MEDIUMINT(5) NOT NULL,
cnd_desc        VARCHAR(150),
                PRIMARY KEY (cng_id),
                UNIQUE (cng_flag),
                INDEX (cng_flag)
);

insert into cengine (cng_flag,cng_value,cnd_desc) values ('CNG_DEBUG',0,'Debug flag');

CREATE TABLE user_logs (
usr_id          MEDIUMINT(8) UNSIGNED NOT NULL,
log_date        VARCHAR(25) NOT NULL,
log_desc        VARCHAR(100) NOT NULL,
log_ip          VARCHAR(15),
                INDEX (usr_id)
);

CREATE TABLE total_stats (
t_impress       MEDIUMINT(9) NOT NULL DEFAULT '0',
t_clicks        MEDIUMINT(9) NOT NULL DEFAULT '0',
td_impress      MEDIUMINT(9) NOT NULL DEFAULT '0',
td_clicks       MEDIUMINT(9) NOT NULL DEFAULT '0',
tc_day          DATE NOT NULL,
ty_impress      MEDIUMINT(9) NOT NULL DEFAULT '0',
ty_clicks       MEDIUMINT(9) NOT NULL DEFAULT '0'
);

#alter table total_stats change tc_day tc_day DATE NOT NULL;

CREATE TABLE def_ratio (
def_credits     MEDIUMINT(9) NOT NULL,
def_impress     VARCHAR(7) NOT NULL,
def_clicks      VARCHAR(7) NOT NULL,
def_referal     VARCHAR(7) NOT NULL,
def_refcred     MEDIUMINT(9) NOT NULL
);

insert into def_ratio values (1000,'1:2','2:3','1:5',1000);

CREATE TABLE exp_banner (
eban_id         TINYINT(2) UNSIGNED NOT NULL auto_increment,
eban_name       VARCHAR(30) NOT NULL,
eban_file       VARCHAR(30) NOT NULL,
eban_url        VARCHAR(150) NOT NULL,
eban_desc       VARCHAR(150) NOT NULL,
eban_type       TINYINT(2) UNSIGNED NOT NULL,
eban_res        TINYINT(2) UNSIGNED NOT NULL,
eban_start      DATE NOT NULL,
eban_stop       DATE NOT NULL,
eban_flag       TINYINT(1) UNSIGNED NOT NULL DEFAULT '0',
                PRIMARY KEY (eban_id),
                INDEX (eban_id)
);

CREATE TABLE ip_black (
ign_ip          VARCHAR(15) NOT NULL,
ign_ipreason    VARCHAR(150) NOT NULL
);


CREATE TABLE faq_category (
cat_id          MEDIUMINT(3) UNSIGNED NOT NULL auto_increment,
cat_name        VARCHAR(150) NOT NULL,
                PRIMARY KEY (cat_id),
                INDEX (cat_id)
);

#alter table faq_category change cat_name cat_name VARCHAR(255) NOT NULL;

CREATE TABLE faq (
faq_id          MEDIUMINT(4) UNSIGNED NOT NULL auto_increment,
faq_q           VARCHAR(255) NOT NULL,
faq_a           VARCHAR(255) NOT NULL,
cat_id          MEDIUMINT(3) UNSIGNED NOT NULL,
                PRIMARY KEY (faq_id),
                INDEX (faq_id,cat_id)
);

CREATE TABLE support (
sup_id          MEDIUMINT(4) UNSIGNED NOT NULL auto_increment,
sup_q           TEXT NOT NULL,
sup_date        DATE NOT NULL,
usr_id          MEDIUMINT(8) UNSIGNED NOT NULL,
                PRIMARY KEY (sup_id),
                INDEX (sup_id)
);

#alter table support change sup_q sup_q TEXT NOT NULL;

insert into total_stats values (0,0,0,0,NOW(),0,0);


#
# ADDONS
# -----------------------------------------------------------------------

CREATE TABLE mail_list (
usr_id          MEDIUMINT(8) UNSIGNED NOT NULL,
sub_email       VARCHAR(100) NOT NULL,
                INDEX (usr_id)
);

CREATE TABLE mail_settings (
usr_id          MEDIUMINT(8) UNSIGNED NOT NULL,
msg_header      TEXT NOT NULL,
msg_footer      TEXT NOT NULL,
page_error      TEXT NOT NULL,
page_subscr     TEXT NOT NULL,
page_unsubscr   TEXT NOT NULL,
ermsg_incor     TEXT NOT NULL,
ermsg_already   TEXT NOT NULL,
ermsg_noexist   TEXT NOT NULL,
                INDEX (usr_id)
);


# Tables for MassMail deamon
# ===================================================================
CREATE TABLE mm_settings (
smtppipe_flg    TINYINT(1) DEFAULT '1' NOT NULL,
smtp_host       VARCHAR(250) DEFAULT 'localhost' NOT NULL,
smtp_port       MEDIUMINT(4) DEFAULT '25' NOT NULL,
pipe_path       VARCHAR(250) DEFAULT "/usr/sbin/sendmail" NOT NULL,
pipe_args       VARCHAR(50) DEFAULT '-oi -t' NOT NULL
);

CREATE TABLE mm_tasks (
mts_id          MEDIUMINT(8) UNSIGNED NOT NULL auto_increment,
mts_date        DATETIME NOT NULL,
mts_message     BLOB NOT NULL,
mts_donedate    DATETIME,
mts_error       VARCHAR(250),
                PRIMARY KEY (mts_id)
);


# Tables for Counter module
# ===================================================================
CREATE TABLE count (
usr_id          MEDIUMINT(8) UNSIGNED NOT NULL,
total_visitors  MEDIUMINT(8) UNSIGNED DEFAULT '0' NOT NULL,
unique_visitors MEDIUMINT(8) UNSIGNED DEFAULT '0' NOT NULL,
                INDEX (usr_id)
);

CREATE TABLE ip_table (
usr_id          MEDIUMINT(8) UNSIGNED NOT NULL,
ip              VARCHAR(15),
                INDEX (usr_id)
);


# Tables for TX2000 module
# ===================================================================
CREATE TABLE banner_tx (
txb_id          MEDIUMINT(8) UNSIGNED NOT NULL auto_increment,
usr_id          MEDIUMINT(8) UNSIGNED NOT NULL,
txb_text        BLOB NOT NULL,
txb_aflag       TINYINT(2) DEFAULT '0' NOT NULL,
txb_url         VARCHAR(100) NOT NULL,
                INDEX (txb_id,usr_id)
);

CREATE TABLE tx_set (
usr_id          MEDIUMINT(8) UNSIGNED NOT NULL,
txs_bgcol       VARCHAR(6) DEFAULT 'FFFFFF' NOT NULL,
txs_fncol       VARCHAR(6) DEFAULT '000000' NOT NULL,
txs_linew       MEDIUMINT(4) DEFAULT '400' NOT NULL,
txs_speed       MEDIUMINT(4) DEFAULT '1' NOT NULL,
                INDEX (usr_id)
);

CREATE TABLE banner_tx_total (
usr_id          MEDIUMINT(8) UNSIGNED NOT NULL,
tx_impress      MEDIUMINT(9) NOT NULL,
tx_clicks       MEDIUMINT(9) NOT NULL,
                INDEX (usr_id)
);

CREATE TABLE tx_credits (
usr_id           MEDIUMINT(8) UNSIGNED NOT NULL,
tx_impress       FLOAT(9,2) NOT NULL,
tx_clicks        FLOAT(9,2) NOT NULL,
tx_defratio      FLOAT(2,2) NOT NULL,
tx_defclickratio FLOAT(2,2) NOT NULL,
                 INDEX (usr_id)
);

CREATE TABLE tx_m_stats (
usr_id          MEDIUMINT(8) UNSIGNED NOT NULL,
txms_string     BLOB NOT NULL,
txlu_year       SMALLINT(4) UNSIGNED NOT NULL,
                INDEX (usr_id)
);

CREATE TABLE tx_d_stats (
usr_id          MEDIUMINT(8) UNSIGNED NOT NULL,
txds_string     BLOB NOT NULL,
txlu_month      TINYINT(2) UNSIGNED NOT NULL,
                INDEX (usr_id)
);

CREATE TABLE tx_h_stats (
usr_id          MEDIUMINT(8) UNSIGNED NOT NULL,
txhs_string     BLOB NOT NULL,
txlu_day        TINYINT(2) UNSIGNED NOT NULL,
                INDEX (usr_id)
);

# SERVER_SET_TX Table
# -------------------
CREATE TABLE server_set_tx (
tx_defratio      FLOAT(2,2) NOT NULL,
tx_defclickratio FLOAT(2,2) NOT NULL,
tx_enable        TINYINT(2) DEFAULT '1' NOT NULL,
tx_enableclick   TINYINT(2) DEFAULT '0' NOT NULL,
tx_startbonus    MEDIUMINT(9) NOT NULL,
tx_minwidth      MEDIUMINT(5) NOT NULL,
tx_maxwidth      MEDIUMINT(5) NOT NULL
);

insert into server_set_tx values (0.5,0.6,1,0,1000,200,600);


# Tables for PopUp Exchange module
# ===================================================================
CREATE TABLE popup_stats (
usr_id          MEDIUMINT(8) UNSIGNED NOT NULL,
pop_jdate       VARCHAR(12) DEFAULT '(N/A)' NOT NULL,
pop_totalpv     MEDIUMINT(9) UNSIGNED DEFAULT '0' NOT NULL,
pop_totalps     MEDIUMINT(9) UNSIGNED DEFAULT '0' NOT NULL,
                INDEX (usr_id)
);

CREATE TABLE popup_credits (
usr_id          MEDIUMINT(8) UNSIGNED NOT NULL,
pop_credits     FLOAT(9,2) NOT NULL,
pop_ratio       VARCHAR(7) NOT NULL,
pop_lastadd     VARCHAR(22) DEFAULT '(N/A)' NOT NULL,
                INDEX (usr_id)
);

CREATE TABLE popup_h_istats (
usr_id          INT UNSIGNED NOT NULL,
i_hr00          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr01          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr02          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr03          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr04          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr05          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr06          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr07          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr08          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr09          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr10          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr11          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr12          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr13          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr14          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr15          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr16          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr17          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr18          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr19          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr20          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr21          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr22          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr23          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_lu_day        TINYINT(2) UNSIGNED NOT NULL,
h_date          DATE,
                INDEX (usr_id,i_lu_day)
);

CREATE TABLE popup_m_istats (
usr_id          INT UNSIGNED NOT NULL,
i_ms01          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ms02          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ms03          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ms04          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ms05          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ms06          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ms07          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ms08          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ms09          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ms10          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ms11          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ms12          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_lu_year       SMALLINT(4) UNSIGNED NOT NULL,
                INDEX (usr_id,i_lu_year)
);

CREATE TABLE popup_d_istats (
usr_id          INT UNSIGNED NOT NULL,
i_ds01          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds02          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds03          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds04          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds05          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds06          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds07          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds08          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds09          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds10          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds11          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds12          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds13          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds14          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds15          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds16          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds17          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds18          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds19          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds20          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds21          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds22          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds23          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds24          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds25          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds26          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds27          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds28          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds29          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds30          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds31          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_lu_month      TINYINT(2) UNSIGNED NOT NULL,
d_date          VARCHAR(7),
                INDEX (usr_id,i_lu_month)
);


# SERVER_SET_POPUP Table
# ----------------------
CREATE TABLE server_set_popup (
pop_enable      TINYINT(2) DEFAULT '1' NOT NULL,
pop_defratio    VARCHAR(7) DEFAULT '1:2' NOT NULL,
pop_width       MEDIUMINT(4) NOT NULL,
pop_height      MEDIUMINT(4) NOT NULL,
pop_startbonus  MEDIUMINT(9) NOT NULL,
pop_delay       MEDIUMINT(4) NOT NULL
);

insert into server_set_popup values (1,'1:2',600,400,1000,15);

CREATE TABLE total_stats_popup (
popts_total     MEDIUMINT(9) NOT NULL,
popts_today     MEDIUMINT(9) NOT NULL,
popts_day       DATE NOT NULL
);

insert into total_stats_popup values (0,0,NOW());


# Tables for StartPage Exchange module
# ===================================================================
CREATE TABLE strx_target (
usr_id          MEDIUMINT(8) UNSIGNED NOT NULL,
grp_tcategory   BLOB NOT NULL,
                INDEX(usr_id)
);

CREATE TABLE strx_stats (
usr_id          MEDIUMINT(8) UNSIGNED NOT NULL,
strx_jdate      VARCHAR(12) DEFAULT '(N/A)' NOT NULL,
strx_totalpv    MEDIUMINT(9) UNSIGNED DEFAULT '0' NOT NULL,
strx_totalps    MEDIUMINT(9) UNSIGNED DEFAULT '0' NOT NULL,
                INDEX (usr_id)
);

CREATE TABLE strx_credits (
usr_id          MEDIUMINT(8) UNSIGNED NOT NULL,
strx_credits    FLOAT(9,2) NOT NULL,
strx_ratio      VARCHAR(7) NOT NULL,
strx_lastadd    VARCHAR(22) DEFAULT '(N/A)' NOT NULL,
                INDEX (usr_id)
);

CREATE TABLE strx_h_istats (
usr_id          INT UNSIGNED NOT NULL,
i_hr00          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr01          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr02          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr03          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr04          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr05          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr06          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr07          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr08          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr09          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr10          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr11          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr12          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr13          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr14          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr15          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr16          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr17          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr18          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr19          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr20          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr21          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr22          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_hr23          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_lu_day        TINYINT(2) UNSIGNED NOT NULL,
h_date          DATE,
                INDEX (usr_id,i_lu_day)
);

CREATE TABLE strx_m_istats (
usr_id          INT UNSIGNED NOT NULL,
i_ms01          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ms02          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ms03          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ms04          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ms05          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ms06          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ms07          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ms08          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ms09          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ms10          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ms11          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ms12          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_lu_year       SMALLINT(4) UNSIGNED NOT NULL,
                INDEX (usr_id,i_lu_year)
);

CREATE TABLE strx_d_istats (
usr_id          INT UNSIGNED NOT NULL,
i_ds01          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds02          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds03          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds04          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds05          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds06          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds07          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds08          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds09          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds10          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds11          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds12          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds13          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds14          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds15          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds16          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds17          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds18          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds19          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds20          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds21          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds22          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds23          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds24          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds25          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds26          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds27          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds28          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds29          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds30          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_ds31          MEDIUMINT(9) NOT NULL DEFAULT '0',
i_lu_month      TINYINT(2) UNSIGNED NOT NULL,
d_date          VARCHAR(7),
                INDEX (usr_id,i_lu_month)
);

# SERVER_SET_STRPG Table
# ----------------------
CREATE TABLE server_set_strx (
strx_enable     TINYINT(2) DEFAULT '1' NOT NULL,
strx_defratio   VARCHAR(7) DEFAULT '1:2' NOT NULL,
strx_startbonus MEDIUMINT(9) DEFAULT '1000' NOT NULL,
strx_refresh    MEDIUMINT(4) DEFAULT '3' NOT NULL,
strx_guard      MEDIUMINT(4) DEFAULT '300' NOT NULL,
strx_delaycreds MEDIUMINT(4) DEFAULT '15' NOT NULL
);

insert into server_set_strx values (1,'1:2',1000,3,300,15);

CREATE TABLE total_stats_strx (
strxs_total     MEDIUMINT(9) NOT NULL,
strxs_today     MEDIUMINT(9) NOT NULL,
strxs_day       DATE NOT NULL
);

insert into total_stats_strx values (0,0,NOW());
